package com.mortals.xhx.module.app.service.impl;

import cn.hutool.core.io.FileUtil;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.framework.service.impl.AbstractCRUDServiceImpl;
import com.mortals.xhx.base.system.upload.service.UploadService;
import com.mortals.xhx.module.app.dao.AppPublishDao;
import com.mortals.xhx.module.app.model.AppPublishEntity;
import com.mortals.xhx.module.app.service.AppPublishService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.io.File;

/**
 * AppPublishService
 * 应用发布部署 service实现
 *
 * @author zxfei
 * @date 2023-02-01
 */
@Service("appPublishService")
public class AppPublishServiceImpl extends AbstractCRUDServiceImpl<AppPublishDao, AppPublishEntity, Long> implements AppPublishService {

    @Autowired
    private UploadService uploadService;

    @Override
    protected void saveBefore(AppPublishEntity entity, Context context) throws AppException {
        String targetPath="/home/mortals/apps/";
        String fileNewName=entity.getAppCode()+"-"+entity.getVersion();

        //将zip包移动到指定目录 并更改名称
        String realFilePath = uploadService.getFilePath(entity.getFilePath());
        if (FileUtil.isEmpty(new File(realFilePath))) {
            throw new AppException("部署文件不存在！");
        }
        if (!FileUtil.getSuffix(entity.getFilePath()).equals("zip")) {
            throw new AppException("部署只支持zip文件！");
        }
        //移动文件并重命名
        FileUtil.move(new File(realFilePath),new File(targetPath+fileNewName),true);

        super.saveBefore(entity, context);
    }
}